@@ -1,8 +1,7 @@
 package segments
 
 type Perl struct {
-	Dummy struct{}
-	language
+	Language
 }
 
 func (p *Perl) Template() string {
@@ -25,5 +24,5 @@ func (p *Perl) Enabled() bool {
 		},
 	}
 
-	return p.language.Enabled()
+	return p.Language.Enabled()
 }
